"use strict";

{
    C3.Plugins.GameAnalytics.Acts =
    {
        addAvailableCustomDimension01(dimension)
        {
            this._customDimensions01.push(dimension);
        },

        addAvailableCustomDimension02(dimension)
        {
            this._customDimensions02.push(dimension);
        },

        addAvailableCustomDimension03(dimension)
        {
            this._customDimensions03.push(dimension);
        },

        addAvailableResourceCurrency(currency)
        {
            this._resourceCurrencies.push(currency);
        },

        addAvailableResourceItemType(itemType)
        {
            this._resourceItemTypes.push(itemType);
        },

        initialize()
        {
            var VERSION = "2.2.3";

            if(typeof window["GameAnalytics"]["initialize"] == "function")
            {
                var ga = window["GameAnalytics"];

                if(this._enableInfoLog)
                {
                    ga["setEnabledInfoLog"](true);
                }
                if(this._enableVerboseLog)
                {
                    ga["setEnabledVerboseLog"](true);
                }
                if(this._enableManualSessionHandling)
                {
                    ga["setEnabledManualSessionHandling"](true);
                }

                if(this._customDimensions01.length > 0)
                {
                    ga["configureAvailableCustomDimensions01"](this._customDimensions01);
                }
                if(this._customDimensions02.length > 0)
                {
                    ga["configureAvailableCustomDimensions02"](this._customDimensions02);
                }
                if(this._customDimensions03.length > 0)
                {
                    ga["configureAvailableCustomDimensions03"](this._customDimensions03);
                }
                if(this._resourceCurrencies.length > 0)
                {
                    ga["configureAvailableResourceCurrencies"](this._resourceCurrencies);
                }
                if(this._resourceItemTypes.length > 0)
                {
                    ga["configureAvailableResourceItemTypes"](this._resourceItemTypes);
                }

                ga["configureBuild"](this._build);

                var sdkVersion = "construct " + VERSION;
                var gameKey = window["device"]["platform"] === "Android" ? this._gameKeyAndroid : this._gameKeyIOS;
                var secretKey = window["device"]["platform"] === "Android" ? this._secretKeyAndroid : this._secretKeyIOS;

                ga["initialize"]({
                    "gameKey": gameKey,
                    "secretKey": secretKey,
                    "sdkVersion": sdkVersion
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                var ga = window["gameanalytics"]["GameAnalytics"];

                if(this._enableInfoLog)
                {
                    ga["setEnabledInfoLog"](true);
                }
                if(this._enableVerboseLog)
                {
                    ga["setEnabledVerboseLog"](true);
                }
                if(this._enableManualSessionHandling)
                {
                    ga["setEnabledManualSessionHandling"](true);
                }

                if(this._customDimensions01.length > 0)
                {
                    ga["configureAvailableCustomDimensions01"](this._customDimensions01);
                }
                if(this._customDimensions02.length > 0)
                {
                    ga["configureAvailableCustomDimensions02"](this._customDimensions02);
                }
                if(this._customDimensions03.length > 0)
                {
                    ga["configureAvailableCustomDimensions03"](this._customDimensions03);
                }
                if(this._resourceCurrencies.length > 0)
                {
                    ga["configureAvailableResourceCurrencies"](this._resourceCurrencies);
                }
                if(this._resourceItemTypes.length > 0)
                {
                    ga["configureAvailableResourceItemTypes"](this._resourceItemTypes);
                }

                ga["configureBuild"](this._build);

                ga["configureSdkGameEngineVersion"]("construct " + VERSION);

                ga["initialize"](this._gameKeyBrowser, this._secretKeyBrowser);
            }
            else
            {
                console.log("initialize: GameAnalytics object not found");
                return;
            }
        },

        addBusinessEvent(currency, amount, itemType, itemId, cartType)
        {
            if(typeof window["GameAnalytics"]["addBusinessEvent"] == "function")
            {
                window["GameAnalytics"]["addBusinessEvent"]({
                    "currency": currency,
                    "amount": amount,
                    "itemType": itemType,
                    "itemId": itemId,
                    "cartType": cartType
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addBusinessEvent"](currency, amount, itemType, itemId, cartType);
            }
            else
            {
                console.log("addBusinessEvent: GameAnalytics object not found");
                return;
            }
        },

        addResourceEvent(flowType, currency, amount, itemType, itemId)
        {
            if(typeof window["GameAnalytics"]["addResourceEvent"] == "function")
            {
                window["GameAnalytics"]["addResourceEvent"]({
                    "flowType": flowType,
                    "currency": currency,
                    "amount": amount,
                    "itemType": itemType,
                    "itemId": itemId
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addResourceEvent"](flowType, currency, amount, itemType, itemId);
            }
            else
            {
                console.log("addResourceEvent: GameAnalytics object not found");
                return;
            }
        },

        addProgressionEvent(progressionStatus, progression01, progression02, progression03)
        {
            if(typeof window["GameAnalytics"]["addProgressionEvent"] == "function")
            {
                window["GameAnalytics"]["addProgressionEvent"]({
                    "progressionStatus": progressionStatus,
                    "progression01": progression01,
                    "progression02": progression02,
                    "progression03": progression03
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addProgressionEvent"](progressionStatus, progression01, progression02, progression03);
            }
            else
            {
                console.log("addProgressionEvent: GameAnalytics object not found");
                return;
            }
        },

        addProgressionEventWithScore(progressionStatus, progression01, progression02, progression03, score)
        {
            if(typeof window["GameAnalytics"]["addProgressionEvent"] == "function")
            {
                window["GameAnalytics"]["addProgressionEvent"]({
                    "progressionStatus": progressionStatus,
                    "progression01": progression01,
                    "progression02": progression02,
                    "progression03": progression03,
                    "score": score
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addProgressionEvent"](progressionStatus, progression01, progression02, progression03, score);
            }
            else
            {
                console.log("addProgressionEventWithScore: GameAnalytics object not found");
                return;
            }
        },

        addDesignEvent(eventId)
        {
            if(typeof window["GameAnalytics"]["addDesignEvent"] == "function")
            {
                window["GameAnalytics"]["addDesignEvent"]({
                    "eventId": eventId
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addDesignEvent"](eventId);
            }
            else
            {
                console.log("addDesignEvent: GameAnalytics object not found");
                return;
            }
        },

        addDesignEventWithValue(eventId, value)
        {
            if(typeof window["GameAnalytics"]["addDesignEvent"] == "function")
            {
                window["GameAnalytics"]["addDesignEvent"]({
                    "eventId": eventId,
                    "value": value
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addDesignEvent"](eventId, value);
            }
            else
            {
                console.log("addDesignEventWithValue: GameAnalytics object not found");
                return;
            }
        },

        addErrorEvent(severity, message)
        {
            if(typeof window["GameAnalytics"]["addErrorEvent"] == "function")
            {
                window["GameAnalytics"]["addErrorEvent"]({
                    "severity": severity,
                    "message": message
                });
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["addErrorEvent"](severity, message);
            }
            else
            {
                console.log("addErrorEvent: GameAnalytics object not found");
                return;
            }
        },

        setEnabledEventSubmission(flag)
        {
            if(typeof window["GameAnalytics"]["setEnabledEventSubmission"] == "function")
            {
                window["GameAnalytics"]["setEnabledEventSubmission"](flag ? true : false);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setEnabledEventSubmission"](flag ? true : false);
            }
            else
            {
                console.log("setEnabledEventSubmission: GameAnalytics object not found");
                return;
            }
        },

        setEnabledManualSessionHandling(flag)
        {
            if(typeof window["GameAnalytics"]["setEnabledManualSessionHandling"] == "function")
            {
                window["GameAnalytics"]["setEnabledManualSessionHandling"](flag ? true : false);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setEnabledManualSessionHandling"](flag ? true : false);
            }
            else
            {
                console.log("setEnabledManualSessionHandling: GameAnalytics object not found");
                return;
            }
        },

        setCustomDimension01(dimension)
        {
            if(typeof window["GameAnalytics"]["setCustomDimension01"] == "function")
            {
                window["GameAnalytics"]["setCustomDimension01"](dimension);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setCustomDimension01"](dimension);
            }
            else
            {
                console.log("setCustomDimension01: GameAnalytics object not found");
                return;
            }
        },

        setCustomDimension02(dimension)
        {
            if(typeof window["GameAnalytics"]["setCustomDimension02"] == "function")
            {
                window["GameAnalytics"]["setCustomDimension02"](dimension);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setCustomDimension02"](dimension);
            }
            else
            {
                console.log("setCustomDimension02: GameAnalytics object not found");
                return;
            }
        },

        setCustomDimension03(dimension)
        {
            if(typeof window["GameAnalytics"]["setCustomDimension03"] == "function")
            {
                window["GameAnalytics"]["setCustomDimension03"](dimension);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setCustomDimension03"](dimension);
            }
            else
            {
                console.log("setCustomDimension03: GameAnalytics object not found");
                return;
            }
        },

        setFacebookId(facebookId)
        {
            if(typeof window["GameAnalytics"]["setFacebookId"] == "function")
            {
                window["GameAnalytics"]["setFacebookId"](facebookId);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setFacebookId"](facebookId);
            }
            else
            {
                console.log("setFacebookId: GameAnalytics object not found");
                return;
            }
        },

        setGender(gender)
        {
            if(typeof window["GameAnalytics"]["setGender"] == "function")
            {
                window["GameAnalytics"]["setGender"](gender);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setGender"](gender);
            }
            else
            {
                console.log("setGender: GameAnalytics object not found");
                return;
            }
        },

        setBirthYear(birthYear)
        {
            if(typeof window["GameAnalytics"]["setBirthYear"] == "function")
            {
                window["GameAnalytics"]["setBirthYear"](birthYear);
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["setBirthYear"](birthYear);
            }
            else
            {
                console.log("setBirthYear: GameAnalytics object not found");
                return;
            }
        },

        startSession()
        {
            if(typeof window["GameAnalytics"]["startSession"] == "function")
            {
                window["GameAnalytics"]["startSession"]();
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["startSession"]();
            }
            else
            {
                console.log("startSession: GameAnalytics object not found");
                return;
            }
        },

        endSession()
        {
            if(typeof window["GameAnalytics"]["endSession"] == "function")
            {
                window["GameAnalytics"]["endSession"]();
            }
            else if(typeof window["gameanalytics"]["GameAnalytics"] != "undefined")
            {
                window["gameanalytics"]["GameAnalytics"]["endSession"]();
            }
            else
            {
                console.log("endSession: GameAnalytics object not found");
                return;
            }
        },

        configureBuild(buildNumber)
        {
            this._build = buildNumber;
        }
    };
}
